<?php

$LANG = array(

#header.php
'MENU'					=> 'Menu',
'HOME'					=> 'Home',
'GOTO_CONTENT'			=> 'Vai al contenuto',
'GOTO_MENU'				=> 'Vai al menu',
'COMMENTS_RSS_FEEDS'	=> 'Feed dei commenti',
'COMMENTS'				=> 'Commenti',
'ARTICLES_RSS_FEEDS'	=> 'Feed degli articoli',
'ARTICLES'				=> 'Articoli',

# sidebar.php
'CATEGORIES' 			=> 'Categorie',
'LATEST_ARTICLES'		=> 'Ultimi articoli',
'LATEST_COMMENTS'		=> 'Ultimi commenti',
'ARCHIVES'				=> 'Archivio',

# footer.php
'POWERED_BY'			=> 'Powered by',
'PLUXML_DESCRIPTION'	=> 'Blog o Cms senza database',
'IN'					=> 'in',
'ADMINISTRATION'		=> 'Amministrazione',
'GOTO_TOP'				=> 'Ritorna in alto',
'TOP'					=> 'Inizio',

# erreur.php
'ERROR'					=> 'E&egrave; stato rilevato un errore',
'BACKTO_HOME'			=> 'Ritorna alla pagina principale',

# common
'WRITTEN_BY'			=> 'Pubblicato da',
'CLASSIFIED_IN'			=> 'Categoria',
'TAGS'					=> 'Tag',

# commentaires.php
'SAID'					=> 'ha detto',
'WRITE_A_COMMENT'		=> 'Scrivi',
'NAME'					=> 'Nome',
'WEBSITE'				=> 'Sito (facoltativo)',
'EMAIL'					=> 'Email (facoltativo)',
'COMMENT'				=> 'Commento',
'CLEAR'					=> 'Cancella',
'SEND'					=> 'Invia',
'COMMENTS_CLOSED'		=> 'Commenti bloccati',
'ANTISPAM_WARNING'		=> 'Verifica antispam',

'REPLY'					=> 'Rispondere',
'REPLY_TO'				=> 'Rispondere',
'CANCEL'				=> 'Annullare',

);

?>
